<?php

namespace Drupal\form_helper_widget\Plugin\field_group\FieldGroupFormatter;

use Drupal\field_group\FieldGroupFormatterBase;

/**
 * Form Helper group element.
 *
 * @FieldGroupFormatter(
 *   id = "form_helper_field_group",
 *   label = @Translation("Helper group"),
 *   description = @Translation("Wrap fields and add description"),
 *   supported_contexts = {
 *     "form",
 *     "view"
 *   }
 * )
 */
class FormHelperFieldGroup extends FieldGroupFormatterBase {

  /**
   * Field title.
   *
   * @const string
   */
  const FIELD_TITLE = 'title';

  /**
   * Field description.
   *
   * @const string
   */
  const FIELD_DESCRIPTION = 'description';

  /**
   * {@inheritdoc}
   */
  public function preRender(&$element, $rendering_object) {
    parent::preRender($element, $rendering_object);
    $content = [
      '#type' => 'container',
    ];
    $content[] = [
      '#theme'       => 'form_helper_widget',
      '#title'       => $this->getSetting(static::FIELD_TITLE),
      '#description' => [
        '#type'   => 'processed_text',
        '#text'   => $this->getSetting(static::FIELD_DESCRIPTION)['value'],
        '#format' => $this->getSetting(static::FIELD_DESCRIPTION)['format'],
      ],
      '#content'     => $element,
    ];
    $element = [
      '#type'   => 'container',
      'content' => $content,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm() {
    $form = parent::settingsForm();

    $form[static::FIELD_TITLE] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Title'),
      '#default_value' => $this->getSetting(static::FIELD_TITLE),
      '#required'      => TRUE,
    ];

    $description = $this->getSetting(static::FIELD_DESCRIPTION);
    $form[static::FIELD_DESCRIPTION] = [
      '#type'          => 'text_format',
      '#format'        => array_key_exists('format', $description) ? $description['format'] : 'full_html',
      '#title'         => $this->t('Description'),
      '#default_value' => array_key_exists('value', $description) ? $description['value'] : '',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    $summary[] = $this->getSetting(static::FIELD_TITLE);

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultContextSettings($context) {
    $defaults = [
      static::FIELD_DESCRIPTION => ['format' => 'full_html'],
      'required_fields'         => $context == 'form',
    ] + parent::defaultContextSettings($context);

    return $defaults;
  }

}
